# ory_keto

OryKeto - JavaScript client for ory_keto
A cloud native access control server providing best-practice patterns (RBAC, ABAC, ACL, AWS IAM Policies, Kubernetes Roles, ...) via REST APIs.
This SDK is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: Latest
- Package version: Latest
- Build package: io.swagger.codegen.languages.JavascriptClientCodegen
For more information, please visit [https://www.ory.sh](https://www.ory.sh)

## Installation

### For [Node.js](https://nodejs.org/)

#### npm

To publish the library as a [npm](https://www.npmjs.com/),
please follow the procedure in ["Publishing npm packages"](https://docs.npmjs.com/getting-started/publishing-npm-packages).

Then install it via:

```shell
npm install ory_keto --save
```

##### Local development

To use the library locally without publishing to a remote npm registry, first install the dependencies by changing 
into the directory containing `package.json` (and this README). Let's call this `JAVASCRIPT_CLIENT_DIR`. Then run:

```shell
npm install
```

Next, [link](https://docs.npmjs.com/cli/link) it globally in npm with the following, also from `JAVASCRIPT_CLIENT_DIR`:

```shell
npm link
```

Finally, switch to the directory you want to use your ory_keto from, and run:

```shell
npm link /path/to/<JAVASCRIPT_CLIENT_DIR>
```

You should now be able to `require('ory_keto')` in javascript files from the directory you ran the last 
command above from.

#### git
#
If the library is hosted at a git repository, e.g.
https://github.com/GIT_USER_ID/GIT_REPO_ID
then install it via:

```shell
    npm install GIT_USER_ID/GIT_REPO_ID --save
```

### For browser

The library also works in the browser environment via npm and [browserify](http://browserify.org/). After following
the above steps with Node.js and installing browserify with `npm install -g browserify`,
perform the following (assuming *main.js* is your entry file, that's to say your javascript file where you actually 
use this library):

```shell
browserify main.js > bundle.js
```

Then include *bundle.js* in the HTML pages.

### Webpack Configuration

Using Webpack you may encounter the following error: "Module not found: Error:
Cannot resolve module", most certainly you should disable AMD loader. Add/merge
the following section to your webpack config:

```javascript
module: {
  rules: [
    {
      parser: {
        amd: false
      }
    }
  ]
}
```

## Getting Started

Please follow the [installation](#installation) instruction and execute the following JS code:

```javascript
var OryKeto = require('ory_keto');

var api = new OryKeto.EnginesApi()

var flavor = "flavor_example"; // {String} The ORY Access Control Policy flavor. Can be \"regex\", \"glob\", and \"exact\".

var id = "id_example"; // {String} The ID of the ORY Access Control Policy Role.

var opts = { 
  'body': new OryKeto.AddOryAccessControlPolicyRoleMembersBody() // {AddOryAccessControlPolicyRoleMembersBody} 
};

var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
};
api.addOryAccessControlPolicyRoleMembers(flavor, id, opts, callback);

```

## Documentation for API Endpoints

All URIs are relative to *http://localhost*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*OryKeto.EnginesApi* | [**addOryAccessControlPolicyRoleMembers**](docs/EnginesApi.md#addOryAccessControlPolicyRoleMembers) | **PUT** /engines/acp/ory/{flavor}/roles/{id}/members | Add a member to an ORY Access Control Policy Role
*OryKeto.EnginesApi* | [**deleteOryAccessControlPolicy**](docs/EnginesApi.md#deleteOryAccessControlPolicy) | **DELETE** /engines/acp/ory/{flavor}/policies/{id} | 
*OryKeto.EnginesApi* | [**deleteOryAccessControlPolicyRole**](docs/EnginesApi.md#deleteOryAccessControlPolicyRole) | **DELETE** /engines/acp/ory/{flavor}/roles/{id} | Delete an ORY Access Control Policy Role
*OryKeto.EnginesApi* | [**doOryAccessControlPoliciesAllow**](docs/EnginesApi.md#doOryAccessControlPoliciesAllow) | **POST** /engines/acp/ory/{flavor}/allowed | Check if a request is allowed
*OryKeto.EnginesApi* | [**getOryAccessControlPolicy**](docs/EnginesApi.md#getOryAccessControlPolicy) | **GET** /engines/acp/ory/{flavor}/policies/{id} | 
*OryKeto.EnginesApi* | [**getOryAccessControlPolicyRole**](docs/EnginesApi.md#getOryAccessControlPolicyRole) | **GET** /engines/acp/ory/{flavor}/roles/{id} | Get an ORY Access Control Policy Role
*OryKeto.EnginesApi* | [**listOryAccessControlPolicies**](docs/EnginesApi.md#listOryAccessControlPolicies) | **GET** /engines/acp/ory/{flavor}/policies | 
*OryKeto.EnginesApi* | [**listOryAccessControlPolicyRoles**](docs/EnginesApi.md#listOryAccessControlPolicyRoles) | **GET** /engines/acp/ory/{flavor}/roles | List ORY Access Control Policy Roles
*OryKeto.EnginesApi* | [**removeOryAccessControlPolicyRoleMembers**](docs/EnginesApi.md#removeOryAccessControlPolicyRoleMembers) | **DELETE** /engines/acp/ory/{flavor}/roles/{id}/members/{member} | Remove a member from an ORY Access Control Policy Role
*OryKeto.EnginesApi* | [**upsertOryAccessControlPolicy**](docs/EnginesApi.md#upsertOryAccessControlPolicy) | **PUT** /engines/acp/ory/{flavor}/policies | 
*OryKeto.EnginesApi* | [**upsertOryAccessControlPolicyRole**](docs/EnginesApi.md#upsertOryAccessControlPolicyRole) | **PUT** /engines/acp/ory/{flavor}/roles | Upsert an ORY Access Control Policy Role
*OryKeto.HealthApi* | [**isInstanceAlive**](docs/HealthApi.md#isInstanceAlive) | **GET** /health/alive | Check alive status
*OryKeto.HealthApi* | [**isInstanceReady**](docs/HealthApi.md#isInstanceReady) | **GET** /health/ready | Check readiness status
*OryKeto.VersionApi* | [**getVersion**](docs/VersionApi.md#getVersion) | **GET** /version | Get service version


## Documentation for Models

 - [OryKeto.AddOryAccessControlPolicyRoleMembers](docs/AddOryAccessControlPolicyRoleMembers.md)
 - [OryKeto.AddOryAccessControlPolicyRoleMembersBody](docs/AddOryAccessControlPolicyRoleMembersBody.md)
 - [OryKeto.AddOryAccessControlPolicyRoleMembersInternalServerError](docs/AddOryAccessControlPolicyRoleMembersInternalServerError.md)
 - [OryKeto.AddOryAccessControlPolicyRoleMembersInternalServerErrorBody](docs/AddOryAccessControlPolicyRoleMembersInternalServerErrorBody.md)
 - [OryKeto.AddOryAccessControlPolicyRoleMembersOK](docs/AddOryAccessControlPolicyRoleMembersOK.md)
 - [OryKeto.AddOryAccessControlPolicyRoleMembersReader](docs/AddOryAccessControlPolicyRoleMembersReader.md)
 - [OryKeto.AuthorizationResult](docs/AuthorizationResult.md)
 - [OryKeto.Context](docs/Context.md)
 - [OryKeto.DeleteOryAccessControlPolicy](docs/DeleteOryAccessControlPolicy.md)
 - [OryKeto.DeleteOryAccessControlPolicyCreated](docs/DeleteOryAccessControlPolicyCreated.md)
 - [OryKeto.DeleteOryAccessControlPolicyInternalServerError](docs/DeleteOryAccessControlPolicyInternalServerError.md)
 - [OryKeto.DeleteOryAccessControlPolicyInternalServerErrorBody](docs/DeleteOryAccessControlPolicyInternalServerErrorBody.md)
 - [OryKeto.DeleteOryAccessControlPolicyNoContent](docs/DeleteOryAccessControlPolicyNoContent.md)
 - [OryKeto.DeleteOryAccessControlPolicyReader](docs/DeleteOryAccessControlPolicyReader.md)
 - [OryKeto.DeleteOryAccessControlPolicyRole](docs/DeleteOryAccessControlPolicyRole.md)
 - [OryKeto.DeleteOryAccessControlPolicyRoleCreated](docs/DeleteOryAccessControlPolicyRoleCreated.md)
 - [OryKeto.DeleteOryAccessControlPolicyRoleInternalServerError](docs/DeleteOryAccessControlPolicyRoleInternalServerError.md)
 - [OryKeto.DeleteOryAccessControlPolicyRoleInternalServerErrorBody](docs/DeleteOryAccessControlPolicyRoleInternalServerErrorBody.md)
 - [OryKeto.DeleteOryAccessControlPolicyRoleNoContent](docs/DeleteOryAccessControlPolicyRoleNoContent.md)
 - [OryKeto.DeleteOryAccessControlPolicyRoleReader](docs/DeleteOryAccessControlPolicyRoleReader.md)
 - [OryKeto.DoOryAccessControlPoliciesAllow](docs/DoOryAccessControlPoliciesAllow.md)
 - [OryKeto.DoOryAccessControlPoliciesAllowForbidden](docs/DoOryAccessControlPoliciesAllowForbidden.md)
 - [OryKeto.DoOryAccessControlPoliciesAllowInternalServerError](docs/DoOryAccessControlPoliciesAllowInternalServerError.md)
 - [OryKeto.DoOryAccessControlPoliciesAllowInternalServerErrorBody](docs/DoOryAccessControlPoliciesAllowInternalServerErrorBody.md)
 - [OryKeto.DoOryAccessControlPoliciesAllowOK](docs/DoOryAccessControlPoliciesAllowOK.md)
 - [OryKeto.DoOryAccessControlPoliciesAllowReader](docs/DoOryAccessControlPoliciesAllowReader.md)
 - [OryKeto.GetOryAccessControlPolicy](docs/GetOryAccessControlPolicy.md)
 - [OryKeto.GetOryAccessControlPolicyInternalServerError](docs/GetOryAccessControlPolicyInternalServerError.md)
 - [OryKeto.GetOryAccessControlPolicyInternalServerErrorBody](docs/GetOryAccessControlPolicyInternalServerErrorBody.md)
 - [OryKeto.GetOryAccessControlPolicyNotFound](docs/GetOryAccessControlPolicyNotFound.md)
 - [OryKeto.GetOryAccessControlPolicyNotFoundBody](docs/GetOryAccessControlPolicyNotFoundBody.md)
 - [OryKeto.GetOryAccessControlPolicyOK](docs/GetOryAccessControlPolicyOK.md)
 - [OryKeto.GetOryAccessControlPolicyReader](docs/GetOryAccessControlPolicyReader.md)
 - [OryKeto.GetOryAccessControlPolicyRole](docs/GetOryAccessControlPolicyRole.md)
 - [OryKeto.GetOryAccessControlPolicyRoleInternalServerError](docs/GetOryAccessControlPolicyRoleInternalServerError.md)
 - [OryKeto.GetOryAccessControlPolicyRoleInternalServerErrorBody](docs/GetOryAccessControlPolicyRoleInternalServerErrorBody.md)
 - [OryKeto.GetOryAccessControlPolicyRoleNotFound](docs/GetOryAccessControlPolicyRoleNotFound.md)
 - [OryKeto.GetOryAccessControlPolicyRoleNotFoundBody](docs/GetOryAccessControlPolicyRoleNotFoundBody.md)
 - [OryKeto.GetOryAccessControlPolicyRoleOK](docs/GetOryAccessControlPolicyRoleOK.md)
 - [OryKeto.GetOryAccessControlPolicyRoleReader](docs/GetOryAccessControlPolicyRoleReader.md)
 - [OryKeto.HealthNotReadyStatus](docs/HealthNotReadyStatus.md)
 - [OryKeto.HealthStatus](docs/HealthStatus.md)
 - [OryKeto.InlineResponse500](docs/InlineResponse500.md)
 - [OryKeto.Input](docs/Input.md)
 - [OryKeto.IsInstanceAliveInternalServerError](docs/IsInstanceAliveInternalServerError.md)
 - [OryKeto.IsInstanceAliveInternalServerErrorBody](docs/IsInstanceAliveInternalServerErrorBody.md)
 - [OryKeto.IsInstanceAliveOK](docs/IsInstanceAliveOK.md)
 - [OryKeto.IsInstanceAliveReader](docs/IsInstanceAliveReader.md)
 - [OryKeto.ListOryAccessControlPolicies](docs/ListOryAccessControlPolicies.md)
 - [OryKeto.ListOryAccessControlPoliciesInternalServerError](docs/ListOryAccessControlPoliciesInternalServerError.md)
 - [OryKeto.ListOryAccessControlPoliciesInternalServerErrorBody](docs/ListOryAccessControlPoliciesInternalServerErrorBody.md)
 - [OryKeto.ListOryAccessControlPoliciesOK](docs/ListOryAccessControlPoliciesOK.md)
 - [OryKeto.ListOryAccessControlPoliciesReader](docs/ListOryAccessControlPoliciesReader.md)
 - [OryKeto.ListOryAccessControlPolicyRoles](docs/ListOryAccessControlPolicyRoles.md)
 - [OryKeto.ListOryAccessControlPolicyRolesInternalServerError](docs/ListOryAccessControlPolicyRolesInternalServerError.md)
 - [OryKeto.ListOryAccessControlPolicyRolesInternalServerErrorBody](docs/ListOryAccessControlPolicyRolesInternalServerErrorBody.md)
 - [OryKeto.ListOryAccessControlPolicyRolesOK](docs/ListOryAccessControlPolicyRolesOK.md)
 - [OryKeto.ListOryAccessControlPolicyRolesReader](docs/ListOryAccessControlPolicyRolesReader.md)
 - [OryKeto.OryAccessControlPolicies](docs/OryAccessControlPolicies.md)
 - [OryKeto.OryAccessControlPolicy](docs/OryAccessControlPolicy.md)
 - [OryKeto.OryAccessControlPolicyAllowedInput](docs/OryAccessControlPolicyAllowedInput.md)
 - [OryKeto.OryAccessControlPolicyRole](docs/OryAccessControlPolicyRole.md)
 - [OryKeto.OryAccessControlPolicyRoles](docs/OryAccessControlPolicyRoles.md)
 - [OryKeto.Policies](docs/Policies.md)
 - [OryKeto.Policy](docs/Policy.md)
 - [OryKeto.RemoveOryAccessControlPolicyRoleMembers](docs/RemoveOryAccessControlPolicyRoleMembers.md)
 - [OryKeto.RemoveOryAccessControlPolicyRoleMembersCreated](docs/RemoveOryAccessControlPolicyRoleMembersCreated.md)
 - [OryKeto.RemoveOryAccessControlPolicyRoleMembersInternalServerError](docs/RemoveOryAccessControlPolicyRoleMembersInternalServerError.md)
 - [OryKeto.RemoveOryAccessControlPolicyRoleMembersInternalServerErrorBody](docs/RemoveOryAccessControlPolicyRoleMembersInternalServerErrorBody.md)
 - [OryKeto.RemoveOryAccessControlPolicyRoleMembersReader](docs/RemoveOryAccessControlPolicyRoleMembersReader.md)
 - [OryKeto.Role](docs/Role.md)
 - [OryKeto.Roles](docs/Roles.md)
 - [OryKeto.SwaggerHealthStatus](docs/SwaggerHealthStatus.md)
 - [OryKeto.SwaggerNotReadyStatus](docs/SwaggerNotReadyStatus.md)
 - [OryKeto.SwaggerVersion](docs/SwaggerVersion.md)
 - [OryKeto.UpsertOryAccessControlPolicy](docs/UpsertOryAccessControlPolicy.md)
 - [OryKeto.UpsertOryAccessControlPolicyInternalServerError](docs/UpsertOryAccessControlPolicyInternalServerError.md)
 - [OryKeto.UpsertOryAccessControlPolicyInternalServerErrorBody](docs/UpsertOryAccessControlPolicyInternalServerErrorBody.md)
 - [OryKeto.UpsertOryAccessControlPolicyOK](docs/UpsertOryAccessControlPolicyOK.md)
 - [OryKeto.UpsertOryAccessControlPolicyReader](docs/UpsertOryAccessControlPolicyReader.md)
 - [OryKeto.UpsertOryAccessControlPolicyRole](docs/UpsertOryAccessControlPolicyRole.md)
 - [OryKeto.UpsertOryAccessControlPolicyRoleInternalServerError](docs/UpsertOryAccessControlPolicyRoleInternalServerError.md)
 - [OryKeto.UpsertOryAccessControlPolicyRoleInternalServerErrorBody](docs/UpsertOryAccessControlPolicyRoleInternalServerErrorBody.md)
 - [OryKeto.UpsertOryAccessControlPolicyRoleOK](docs/UpsertOryAccessControlPolicyRoleOK.md)
 - [OryKeto.UpsertOryAccessControlPolicyRoleReader](docs/UpsertOryAccessControlPolicyRoleReader.md)
 - [OryKeto.Version](docs/Version.md)


## Documentation for Authorization

 All endpoints do not require authorization.

